# RPG Dice

[![Build Status](https://travis-ci.org/pfertyk/rpg-dice.svg?branch=master)](https://travis-ci.org/pfertyk/rpg-dice)

A simple dice parser for RPG sessions. Currently only handles dice of the same
kind.

## Usage

```python
from rpg_dice import roll
value = roll("2d6")
```
